@@ -1,3 +1,20 @@
+# python-cc1101 - Python Library to Transmit RF Signals via C1101 Transceivers
+#
+# Copyright (C) 2020 Fabian Peter Hammerle <fabian@hammerle.me>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 import contextlib
 import enum
 import logging
@@ -302,13 +319,13 @@ class CC1101:
             raise ValueError("expected marcstate idle (actual: {})".format(marcstate))
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback) -> bool:
+    def __exit__(self, exc_type, exc_value, traceback):  # -> typing.Literal[False]
         # https://docs.python.org/3/reference/datamodel.html#object.__exit__
         self._spi.close()
         return False
 
     def get_main_radio_control_state_machine_state(
-        self
+        self,
     ) -> MainRadioControlStateMachineState:
         return MainRadioControlStateMachineState(
             self._read_status_register(StatusRegisterAddress.MARCSTATE)
@@ -411,6 +428,21 @@ class CC1101:
             start_register=ConfigurationRegisterAddress.PKTCTRL0, values=[pktctrl0]
         )
 
+    def disable_checksum(self) -> None:
+        """
+        PKTCTRL0.CRC_EN
+
+        Disable automatic 2-byte cyclic redundancy check (CRC) sum
+        appending in TX mode and checking in RX mode.
+
+        See "Figure 19: Packet Format".
+        """
+        pktctrl0 = self._read_single_byte(ConfigurationRegisterAddress.PKTCTRL0)
+        pktctrl0 &= 0b11111011
+        self._write_burst(
+            start_register=ConfigurationRegisterAddress.PKTCTRL0, values=[pktctrl0]
+        )
+
     def _get_transceive_mode(self) -> _TransceiveMode:
         pktctrl0 = self._read_single_byte(ConfigurationRegisterAddress.PKTCTRL0)
         return _TransceiveMode((pktctrl0 >> 4) & 0b11)
@@ -430,6 +462,9 @@ class CC1101:
         self._command_strobe(StrobeAddress.SFTX)
 
     def transmit(self, payload: bytes) -> None:
+        """
+        The most significant bit is transmitted first.
+        """
         # see "15.2 Packet Format"
         # > In variable packet length mode, [...]
         # > The first byte written to the TXFIFO must be different from 0.
